The Topic Modeling Neural Toolkit (TMNT) is a software library that enables training
topic models as neural network-based variational auto-encoders.

Current stable version is: 0.7.46

Documentation can be found here: https://tmnt.readthedocs.io/en/stable/

The latest development version documentation is here: https://tmnt.readthedocs.io/en/latest

